@@ -179,7 +179,7 @@ static int SkipSpace(char *text, char *text2)
 {
  int erg, lgkl, daz, index, inmakro;
  char *zaehler;
- 
+
  index = 0;
  lgkl = 0;
  daz = 0;
@@ -305,6 +305,11 @@ static int SkipSpace(char *text, char *text2)
      index++;
      inmakro = 0;
    } 
+   else if (*text == '-') {        /* - */
+     *zaehler++ = *text;
+     text++;
+     index++;
+   } 
    else {                        /* sonstiges Zeichen in String */
      *zaehler++ = *text;
      text++;
@@ -314,7 +319,6 @@ static int SkipSpace(char *text, char *text2)
  }
  *zaehler++ = '\0';
  return erg;
-  
 }
 
 static void PushSign(Snode **w, char a)
@@ -527,9 +531,8 @@ Errcode bifFileRead(BibPtr bp)
 Errcode bifFileWrite(BibPtr bp)
 {
  char sysStr[2*MAX_FILEPATHLEN];
- CardListNode *cl = NULL;
- char wcKey[] = ".";
- CardData *wcCard;
+ CardListNode *cl1 = NULL;
+ CardListNode *cl2 = NULL;
  Errcode status;
 
  if (bp->macrofile!=NULL){
@@ -543,20 +546,24 @@ Errcode bifFileWrite(BibPtr bp)
 
  if (tempDatei == NULL) return BIF_EWRITE;
 
-   /* build list with wildcard search */
-   if ((status = (int)dbtMakeCard(&wcCard)) != OK) {
-      guwError(status);
-   }
-   wcCard->cardtype = (int)regexpr;
-   wcCard->mainkey = glbNewString(".");
-   if ((status = dbtSearchList(bp->treeIdx, wcCard, &cl, bp->sortedby)) != OK) {
+   /* build list */
+   if ((status = dbtBuildList(bp->treeIdx, &cl1, bp->sortedby)) != OK) {
       guwError(status); 
       return(status);
    }
 
- while (cl != NULL) {
-   WriteRecToFile(cl->data, tempDatei);
-   cl = cl->next;
+ cl2 = cl1; 
+
+ while (cl1 != NULL) {
+   if (!glbIsStringEmpty(cl1->data->field[ncrossref]))
+      WriteRecToFile(cl1->data, tempDatei);
+   cl1 = cl1->next;
+ } 
+
+ while (cl2 != NULL) {
+   if (glbIsStringEmpty(cl2->data->field[ncrossref]))
+      WriteRecToFile(cl2->data, tempDatei);
+   cl2 = cl2->next;
  } 
 
  fclose(tempDatei);
@@ -584,9 +591,18 @@ Errcode bifFileListWrite(BibPtr bp, CardListNode *list, String fname)
  if (tempDatei == NULL) return BIF_EWRITE;
  hlist = list;
  while (hlist != NULL) {
-   WriteRecToFile(hlist->data, tempDatei);
+   if (!glbIsStringEmpty(hlist->data->field[ncrossref]))
+      WriteRecToFile(hlist->data, tempDatei);
    hlist = hlist->next;
  } 
+
+ hlist = list;
+ while (hlist != NULL) {
+   if (glbIsStringEmpty(hlist->data->field[ncrossref]))
+      WriteRecToFile(hlist->data, tempDatei);
+   hlist = hlist->next;
+ } 
+
  fclose(tempDatei);
  return BIF_OK;
 }
@@ -643,6 +659,10 @@ static long WriteLineToFile(FILE *datei, char *feld, char *inh)
 		fprintf(datei, "%s", blank);
 		blankptr = blank;
 		}
+             else {
+	        fprintf(datei, "{");
+		instring=1;
+		}
 	     fprintf(datei, "@");
 	     zeichen++;
 	     }
@@ -788,7 +808,7 @@ __YYSCLASS yytabelem yyexca[] ={
 	0, 3,
 	-2, 0,
 	};
-# define YYNPROD 233
+# define YYNPROD 234
 # define YYLAST 573
 __YYSCLASS yytabelem yyact[]={
 
@@ -913,7 +933,7 @@ __YYSCLASS yytabelem yyr1[]={
     21,    21,    23,    23,    23,    23,    23,    23,    23,    23,
     23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
     23,    23,    23,    23,    23,    23,    23,    23,    23,    23,
-    23,    23,    23 };
+    23,    23,    23,    23 };
 __YYSCLASS yytabelem yyr2[]={
 
      0,     4,     4,     2,     2,     2,     2,     2,     2,     2,
@@ -939,7 +959,7 @@ __YYSCLASS yytabelem yyr2[]={
      2,     2,     4,     4,     4,     4,     4,     4,     6,     8,
      4,     6,     4,     4,     4,     4,     4,     2,     2,     2,
      4,     4,     4,     2,     2,     2,     2,     2,     2,     2,
-     2,     2,     2 };
+     2,     2,     2,     2 };
 __YYSCLASS yytabelem yychk[]={
 
  -3000,    -1,    -2,    -3,   261,   262,   264,   265,   266,   267,
@@ -1002,8 +1022,8 @@ __YYSCLASS yytabelem yydef[]={
    193,   194,   195,   196,     0,   198,   199,   200,   201,   197,
    164,   165,   154,   158,   159,   160,   168,   169,   170,   171,
    172,   173,   174,   175,   176,   177,     0,   180,   217,   218,
-   219,   223,   224,   225,     0,   229,   230,   231,   232,   228,
-   226,   227,     0,   182,   183,   184,   185,   186,   178,   181,
+   219,   223,   225,   226,     0,   230,   231,   232,   233,   229,
+   227,   228,   224,   182,   183,   184,   185,   186,   178,   181,
    202,   203,   204,   205,   206,   207,     0,   210,   212,   213,
    214,   215,   216,   220,   221,   222,   179,   208,   211,   209 };
 typedef struct { char *t_name; int t_val; } yytoktype;
@@ -1262,6 +1282,7 @@ __YYSCLASS char * yyreds[] =
 	"dazdaz : DAZ dazdaz",
 	"dazdaz : EQ dazdaz",
 	"dazdaz : ZEICHEN",
+	"dazdaz : EQ",
 	"dazdaz : LRKL",
 	"dazdaz : RRKL",
 	"dazdaz : KOMMA",
@@ -1580,9 +1601,8 @@ yyparse()
 			switch ( yyerrflag )
 			{
 			case 0:		/* new error */
-		/*		yyerror( (nl_msg(30003,"syntax error")) ); */
+				yyerror( (nl_msg(30003,"syntax error")) );
 				yynerrs++;
-				errorline = yynline;
 				goto skip_init;
 			yyerrlab:
 				/*
