@@ -138,9 +138,14 @@ String fieldNames[MAX_FIELDS] = {
    "pages",
    "series",
    "type",
-   "category",
    "note",
-   NULL,
+   NULL, NULL,
+   NULL, NULL, NULL, NULL, NULL,
+   NULL, NULL, NULL, NULL, NULL,
+   NULL, NULL, NULL, NULL, NULL,
+   NULL, NULL, NULL, NULL, NULL,
+   NULL, NULL, NULL, NULL, NULL,
+   NULL, NULL, NULL, NULL, NULL,
    NULL, NULL, NULL, NULL, NULL,
    NULL, NULL, NULL, NULL, NULL,
    NULL, NULL, NULL, NULL, NULL,
@@ -175,20 +180,6 @@ static char *fallback_resources[] = {
 
 static char bibfile[MAXPATHLEN+1];
 
-/* command line options */
-typedef struct {
-   Boolean quiet;
-   Boolean iconsOnDesk;
-   Boolean makeBackup;
-   Boolean autoCheck;
-   Boolean reqFields;
-   Boolean ignoreCase;
-   Boolean printAsBib;
-   Boolean displayErrWin;
-   String  bibfile;
-   String  rcfile;
-   String  bibdir;
-} OptionsRec;
 OptionsRec options;
 
 #define Offset(field)  XtOffsetOf(OptionsRec, field)
@@ -209,24 +200,38 @@ XtResource resources[] = {
 	Offset(printAsBib), XtRString, (XtPointer)"True" },
    { "displayErrWin", "DisplayErrWin", XtRBoolean, sizeof(Boolean),
 	Offset(displayErrWin), XtRString, (XtPointer)"True" },
+   { "focus", "Focus", XtRBoolean, sizeof(Boolean),
+	Offset(focus), XtRString, (XtPointer)"True" },
    { "bibfile", "Bibfile", XtRString, sizeof(String),
 	Offset(bibfile), XtRString, (XtPointer)NULL },
    { "rcfile", "Rcfile", XtRString, sizeof(String),
 	Offset(rcfile), XtRString, (XtPointer)NULL },
    { "bibdir", "Bibdir", XtRString, sizeof(String),
-	Offset(bibdir), XtRString, (XtPointer)NULL }
+	Offset(bibdir), XtRString, (XtPointer)NULL },
+   { "focusColor", "FocusColor", XtRPixel, sizeof(Pixel),
+	Offset(focusColor), XtRString, XtDefaultBackground },
 };
 #undef Offset
 
 static XrmOptionDescRec optionDesc[] = {
    { "-quiet",       "*quiet",       XrmoptionNoArg, (XtPointer)"on" },
+   { "+quiet",       "*quiet",       XrmoptionNoArg, (XtPointer)"off" },
    { "-iconsOnDesk", "*iconsOnDesk", XrmoptionNoArg, (XtPointer)"on" },
+   { "+iconsOnDesk", "*iconsOnDesk", XrmoptionNoArg, (XtPointer)"off" },
    { "-makeBackup",  "*makeBackup",  XrmoptionNoArg, (XtPointer)"on" },
+   { "+makeBackup",  "*makeBackup",  XrmoptionNoArg, (XtPointer)"off" },
    { "-autoCheck",   "*autoCheck",   XrmoptionNoArg, (XtPointer)"on" },
+   { "+autoCheck",   "*autoCheck",   XrmoptionNoArg, (XtPointer)"off" },
    { "-reqFields",   "*reqFields",   XrmoptionNoArg, (XtPointer)"on" },
+   { "+reqFields",   "*reqFields",   XrmoptionNoArg, (XtPointer)"off" },
    { "-ignoreCase",  "*ignoreCase",  XrmoptionNoArg, (XtPointer)"on" },
+   { "+ignoreCase",  "*ignoreCase",  XrmoptionNoArg, (XtPointer)"off" },
    { "-printAsBib",  "*printAsBib",  XrmoptionNoArg, (XtPointer)"on" },
-   { "-displayErrWin"," *displayErrWin",  XrmoptionNoArg, (XtPointer)"on" },
+   { "+printAsBib",  "*printAsBib",  XrmoptionNoArg, (XtPointer)"off" },
+   { "-displayErrWin","*displayErrWin",  XrmoptionNoArg, (XtPointer)"on" },
+   { "+displayErrWin","*displayErrWin",  XrmoptionNoArg, (XtPointer)"off" },
+   { "-focus",        "*focus",      XrmoptionNoArg, (XtPointer)"on" },
+   { "+focus",        "*focus",      XrmoptionNoArg, (XtPointer)"off" },
    { "-rcfile",      "*rcfile",      XrmoptionSepArg, (XtPointer)NULL },
    { "-bibdir",      "*bibdir",      XrmoptionSepArg, (XtPointer)NULL },
    { "-file",        "*bibfile",     XrmoptionSepArg, (XtPointer)NULL } 
@@ -301,11 +306,11 @@ int i;
       (void) getwd(actual_path);
 #endif
    
-   processCommandlineOptions();
    
    fieldNames[nannote] = XtCalloc(7, sizeof(char));
    strcpy(fieldNames[nannote], "annote");
 
+
    /* read rc options file */
    if (options.rcfile != NULL)
       rcfReadCfgFile(options.rcfile);
@@ -324,6 +329,8 @@ int i;
       }
    }
 
+   processCommandlineOptions();
+
    if (options.bibdir != NULL) 
       procDefaultDirLine(options.bibdir);
 
@@ -340,7 +347,6 @@ int i;
    gwmMainWin();
 
    XtRealizeWidget(topLevel);
-   XtInstallAllAccelerators(topLevel, topLevel);  
    
    /* load a file from command line */ 
    if (options.bibfile != NULL)
@@ -359,6 +365,7 @@ int i;
 /* LOCAL FUNCTIONS                                                   */
 /*********************************************************************/
 
+
 /*********************************************************************/
 /* printHelp:                                                        */
 /*   Process excess options and show help                            */
@@ -373,12 +380,20 @@ static char *help[] = {
  "\n",
  "Additional options are as follows:\n",
  "   Option        Valid Range     Function\n",
- "   -quiet        none            Turn on/off beep on error\n",
+ "   -quiet        none            Turn off beep on error\n",
  "   -iconsOnDesk  none            Keep icons on bibview desktop\n",
  "   -makeBackup   none            Save files to backup on save\n",
  "   -autoCheck    none            Turn on/off consistency checking\n",
  "   -reqFields    none            Disallow empty required fields\n",
  "   -ignoreCase   none            Ignore case in search\n",
+ "   -focus        none            Use <tab> and <esc> key in card window\n",
+ "   +quiet        none            Turn on/off beep on error\n",
+ "   +iconsOnDesk  none            Don't keep icons on bibview desktop\n",
+ "   +makeBackup   none            Don't save files to backup on save\n",
+ "   +autoCheck    none            Turn off consistency checking\n",
+ "   +reqFields    none            Allow empty required fields\n",
+ "   +ignoreCase   none            Use case in search\n",
+ "   +focus        none            Use mouse in card window\n",
  "   -file         BibTeX File     Load BibTeX-File on startup\n",
  "   -rcfile       bibview rcFile  Use specific configuration file\n",
  "   -help         none            Show this list\n",
@@ -423,6 +438,7 @@ processCommandlineOptions (void)
    optionsStatus[OPT_IGNORE_CASE]     = options.ignoreCase;
    optionsStatus[OPT_PRINT_AS_BIB]    = options.printAsBib;
    optionsStatus[OPT_DISPLAY_ERRWIN]  = options.displayErrWin;
+   optionsStatus[OPT_FOCUS]           = options.focus;
 }
 
 
@@ -480,7 +496,7 @@ initializeFields (void)
 int i, j;
    
    
-   max_fields = 25;
+   max_fields = 24;
    max_bibtex_types = 14;
    
    list_layout = (listEntry *) XtCalloc(1, sizeof(listEntry));
@@ -491,8 +507,6 @@ int i, j;
    list_layout->width[(list_layout->number)++] = 50;
    list_layout->field[list_layout->number] = nyear; 
    list_layout->width[(list_layout->number)++] = 5;
-   list_layout->field[list_layout->number] = ncategory; 
-   list_layout->width[(list_layout->number)++] = 10;
    list_layout->field[list_layout->number] = -2;  /* BibTeX type */
    list_layout->width[(list_layout->number)++] = 10;
    list_layout->field[list_layout->number] = -1;  /* mainkey */
@@ -508,7 +522,6 @@ int i, j;
       for (j=0; j<max_fields; j++){
          standardfields[i][nmonth] = '1';
          standardfields[i][nyear] = '1';
-         standardfields[i][ncategory] = '1';
          standardfields[i][nnote] = '1';
          standardfields[i][nkey] = '1';
          standardfields[i][nannote] = '1';
@@ -698,7 +711,6 @@ int i, j;
    standardfields[unpublished][nnote] =
    requiredfields[unpublished][nnote] = '1';
       
-   standardfields[MAX_BIBTEX_TYPES][ncategory] = '1';
    standardfields[MAX_BIBTEX_TYPES][nannote] = '1';
    standardfields[MAX_BIBTEX_TYPES][nkey] = '1';
    standardfields[MAX_BIBTEX_TYPES][nnote] = '1';
