@@ -106,7 +106,7 @@ char    *mystrcat(char *s1, char *s2);
 int     dbtSearchAllUserFld(UserFld **list, char *str);
 int     dbtSearchUserFld(UserFld **list, UserFld **reglist);
 Boolean Insert(int treeIdx, AvlNode **tree, CardData *card, int *h);
-Boolean Search(AvlNode *tree, CardData **card);
+Boolean Search(AvlNode *tree, CardData **card, CardListNode **list);
 Boolean Delete(int treeIdx, AvlNode **tree, CardData *card, int *deleted);
 Errcode MakeListNode(ListNode **list);
 Errcode ListAppend(ListNode **list, String word);
@@ -731,9 +731,10 @@ Boolean Delete(int treeIdx, AvlNode **tree, CardData *card, int *deleted)
  * Returns: TRUE     the node was found
  *          FALSE    the node was not found
  */
-Boolean Search(AvlNode *tree, CardData **card)
+Boolean Search(AvlNode *baum, CardData **card, CardListNode **list)
 {
     int result;
+    CardData *tree;
 
     if (tree == NULL) {
         /*
@@ -741,18 +742,19 @@ Boolean Search(AvlNode *tree, CardData **card)
          */
         return FALSE;
     }
-    else if 
-    ((result = KeyCompare((*card)->mainkey, tree->data->mainkey)) < 0) {
-        return (Search(tree->left, card));
+    if 
+    ((result = KeyCompare((*card)->mainkey, baum->data->mainkey)) < 0) {
+        return (Search(baum->left, card, list));
     }
     else if (result > 0) {
-        return (Search(tree->right, card));
+        return (Search(baum->right, card, list));
     }
     else {
         /*
          * key found
          */
-        CopyCard(card, tree->data);
+        tree = baum->data;
+	dbtCardListInsert(list, tree, SORT_UNSRT);
         return TRUE;
     }
 }
@@ -1656,15 +1658,13 @@ Errcode RegCompCard(CardData *card, CardData *reg)
 
 /*********************************************************************/
 /* Errcode dbtSearch(int treeIdx, CardData **card)                   */
-/* eine Karte mit bestimmten Schluessel suchen                       */
+/* eine Karte mit bestimmtem Schluessel suchen und in Liste          */
+/* einfuegen                                                         */
 /*********************************************************************/
-Errcode dbtSearch(int treeIdx, CardData **card)
+Errcode dbtSearch(int treeIdx, CardData **card, CardListNode **list)
 {
-  Boolean erg;
-
-  erg = Search(TreeRoots[treeIdx], card);
-  if (erg) return DBT_OK;
-  else     return DBT_ENONODE;
+  Search(TreeRoots[treeIdx], card, list);
+  return DBT_OK;
 } 
 
 
