@@ -188,6 +188,7 @@
 "BibView*cardWin*Text*textSource.editType:	edit",
 "BibView*cardWin*Text*input: 		true",
 "BibView*cardWin*Label*justify:		left",
+"BibView*cardWin*Label*width:           70",
 "BibView*cardWin.width:			450",
 "BibView*cardWin.borderWidth:		2",
 "BibView*cardWin.commandBox.showGrip:	false",
@@ -202,6 +203,7 @@
 "BibView*cardWin.commandBox*change.label:	Aendern",
 "BibView*cardWin.commandBox*delete.label:	Loeschen",
 "BibView*cardWin.commandBox*copy.label:		Kopieren",
+"BibView*cardWin.commandBox*crossref.label:     Crossref",
 "BibView*cardWin.commandBox*duplicate.label:	Verdoppeln",
 "BibView*cardWin*duplicate.menuName:		duplicateMenu",
 "BibView*cardWin*duplicateMenu.label:		Verdopplen Menu",
@@ -283,6 +285,8 @@
 "BibView*msgText15.label:  Datei kann nicht in sich selbst gemischt werden.",
 "BibView*msgText16.label:  Karte kann nicht auf sich selbst kopiert werden.",
 "BibView*msgText17.label:  Liste kann nicht auf sich selbst kopiert werden.",
+"BibView*msgText18.label:  Crossref leer.",
+"BibView*msgText19.label:  Crossref nicht vorhanden.",
 "BibView*msgText30.label:  Fenster koennen nicht kaskadiert werden!",
 "BibView*msgText50.label:  Datei kann nicht geoeffnet werden!",
 "BibView*msgText51.label:  Keine Konfigurationsdatei angegeben.",
