@@ -188,6 +188,7 @@
 "BibView*cardWin*Text*textSource.editType:	edit",
 "BibView*cardWin*Text*input: 		true",
 "BibView*cardWin*Label*justify:		left",
+"BibView*cardWin*Label*width:           70",
 "BibView*cardWin.width:			450",
 "BibView*cardWin.borderWidth:		2",
 "BibView*cardWin.commandBox.showGrip:	false",
@@ -195,13 +196,14 @@
 "BibView*cardWin.commandBox.vSpace: 	0",
 "BibView*cardWin.commandBox.hSpace: 	0",
 "BibView*cardWin.commandBox.min: 	21",
-"BibView*cardWin.commandBox.skipAdjust: 	false",
+"BibView*cardWin.commandBox.skipAdjust: 	true",
 "BibView*cardWin.commandBox*userDef.label:	UserData",
 "BibView*cardWin.commandBox*annote.label:	Annote",
 "BibView*cardWin.commandBox*save.label:		Save",
 "BibView*cardWin.commandBox*change.label:	Change",
 "BibView*cardWin.commandBox*delete.label:	Delete",
 "BibView*cardWin.commandBox*copy.label:		Copy",
+"BibView*cardWin.commandBox*crossref.label:	Crossref",
 "BibView*cardWin.commandBox*duplicate.label:	Duplicate",
 "BibView*cardWin*duplicate.menuName:		duplicateMenu", 
 "BibView*cardWin*duplicateMenu.label:		Duplicate Menu",
@@ -267,6 +269,8 @@
 "BibView*msgText15.label:  File cannot be unified!.",
 "BibView*msgText16.label:  Card cannot be copied.",
 "BibView*msgText17.label:  List cannot be copied.",
+"BibView*msgText18.label:  Crossref field empty.",
+"BibView*msgText19.label:  Crossref not available.",
 "BibView*msgText30.label:  Windows can't be cascaded!",
 "BibView*msgText50.label:  File can't be opened!",
 "BibView*msgText51.label:  No Configuration file.",
@@ -285,7 +289,7 @@
 "BibView*msgText114.label: Card incomplete: no author or editor.",
 "BibView*msgText115.label: Card incomplete: no chapter and/or page.",
 "BibView*msgText120.label: No further Files loadable.\\nPlease close bibliography.",
-"BibView*msgText121.label: Internal Bug: Nr. 121",
+"BibView*msgText121.label: Internal Error: Nr. 121",
 /*"BibView*quit.accelerators:\ */
 "BibView*fileMenu*quit.accelerators:\
 	<Key>q: notify()", 
