@@ -53,6 +53,7 @@ static Errcode saveWidgets (CardPtr cp);
 extern Widget topLevel, desktop;
 extern Pixmap crdIconPixmap;
 extern UserDefFld userDefFlds[];
+extern OptionsRec options;
 
 extern int max_fields;
 extern char sort_field[];
@@ -65,6 +66,7 @@ extern char sort_field[];
 /* local global variables */
 /* ------------------------- */
 static XtTranslations trans;
+static Pixel back, fore, focus;
 
 static char trans_string[] =
    "<Key>Tab:   forward_focus()\n\
@@ -95,32 +97,29 @@ static void forward_focus(Widget w)
  CardPtr cp;
  CardWidgetsPtr cwp;
  int i;
- Pixel back, fore;
 
  bp = glbFirstBibListEl();
  while (bp!=NULL){
     cp = glbFirstCardListEl(bp);
     while (cp!=NULL){
-       XtVaGetValues(cp->cw->cardWin, XtNbackground, &back, NULL);
-       XtVaGetValues(cp->cw->cardWin, XtNforeground, &fore, NULL);
        cwp = &cp->cw->ct.cw;
        if (w == cwp->mainkey){
           XtVaSetValues(cwp->mainkey, XtNborderColor, fore, NULL);
           if (cwp->owntype){
              XtSetKeyboardFocus(XtParent(w), cwp->owntype);
-             XtVaSetValues(cwp->owntype, XtNborderColor, back, NULL);
+             XtVaSetValues(cwp->owntype, XtNborderColor, focus, NULL);
              return;
              }
           else {
              for (i=0; i< MAX_FIELDS; i++)
             	if (cwp->wfield[2*i+1]){
-                XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, back, NULL);
+                XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, focus, NULL);
                 XtSetKeyboardFocus(XtParent(w), cwp->wfield[2*i+1]);
 	        return;
 	        }
              if (i == MAX_FIELDS){
                XtSetKeyboardFocus(XtParent(w), cwp->mainkey);
-               XtVaSetValues(cwp->mainkey, XtNborderColor, back, NULL);
+               XtVaSetValues(cwp->mainkey, XtNborderColor, focus, NULL);
 	       return;
 	       }
              }
@@ -130,11 +129,11 @@ static void forward_focus(Widget w)
           for (i=0; i< MAX_FIELDS; i++)
              if (cwp->wfield[2*i+1]){
                 XtSetKeyboardFocus(XtParent(w), cwp->wfield[2*i+1]);
-                XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, back, NULL);
+                XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, focus, NULL);
                 return;
                 }
           if (i == MAX_FIELDS){
-             XtVaSetValues(cwp->mainkey, XtNborderColor, back, NULL);
+             XtVaSetValues(cwp->mainkey, XtNborderColor, focus, NULL);
              XtSetKeyboardFocus(XtParent(w), cwp->mainkey);
 	     return;
 	     }
@@ -145,12 +144,12 @@ static void forward_focus(Widget w)
             for (i=i+1; i< MAX_FIELDS; i++)
               if (cwp->wfield[2*i+1]){
                  XtSetKeyboardFocus(XtParent(w), cwp->wfield[2*i+1]);
-                 XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, back, NULL);
+                 XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, focus, NULL);
                  return;
                  }
             if (i == MAX_FIELDS){
                XtSetKeyboardFocus(XtParent(w), cwp->mainkey);
-               XtVaSetValues(cwp->mainkey, XtNborderColor, back, NULL);
+               XtVaSetValues(cwp->mainkey, XtNborderColor, focus, NULL);
                return;
                }
          }
@@ -170,26 +169,23 @@ static void backward_focus(Widget w)
  CardPtr cp;
  CardWidgetsPtr cwp;
  int i;
- Pixel back, fore;
 
  bp = glbFirstBibListEl();
  while (bp!=NULL){
     cp = glbFirstCardListEl(bp);
     while (cp!=NULL){
-      XtVaGetValues(cp->cw->cardWin, XtNbackground, &back, NULL);
-      XtVaGetValues(cp->cw->cardWin, XtNforeground, &fore, NULL);
       cwp = &cp->cw->ct.cw;
       if (w == cwp->mainkey){
          XtVaSetValues(cwp->mainkey, XtNborderColor, fore, NULL);
          for (i=MAX_FIELDS-1; i>=0; i--)
             if (cwp->wfield[2*i+1]){
-               XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, back, NULL);
+               XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, focus, NULL);
                XtSetKeyboardFocus(XtParent(w), cwp->wfield[2*i+1]);
                return;
                }
          if (i < 0){
             if (cwp->owntype){
-               XtVaSetValues(cwp->owntype, XtNborderColor, back, NULL);
+               XtVaSetValues(cwp->owntype, XtNborderColor, focus, NULL);
                XtSetKeyboardFocus(XtParent(w), cwp->owntype);
                return;
                }
@@ -203,7 +199,7 @@ static void backward_focus(Widget w)
       if (w == cwp->owntype){
          XtVaSetValues(cwp->owntype, XtNborderColor, fore, NULL);
          XtSetKeyboardFocus(XtParent(w), cwp->mainkey);
-         XtVaSetValues(cwp->mainkey, XtNborderColor, back, NULL);
+         XtVaSetValues(cwp->mainkey, XtNborderColor, focus, NULL);
          return;
          }
       for (i=MAX_FIELDS-1; i>=0; i--)
@@ -212,18 +208,19 @@ static void backward_focus(Widget w)
             for (i=i-1; i>=0; i--)
                if (cwp->wfield[2*i+1]){
                   XtSetKeyboardFocus(XtParent(w), cwp->wfield[2*i+1]);
-                  XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, back, NULL);
+                  XtVaSetValues(cwp->wfield[2*i+1], 
+		      XtNborderColor, focus, NULL);
                   return;
                   }
             if (i < 0){
                if (cwp->owntype){
                   XtSetKeyboardFocus(XtParent(w), cwp->owntype);
-                  XtVaSetValues(cwp->owntype, XtNborderColor, back, NULL);
+                  XtVaSetValues(cwp->owntype, XtNborderColor, focus, NULL);
                   return;
                   }
                else{
                   XtSetKeyboardFocus(XtParent(w), cwp->mainkey);
-                  XtVaSetValues(cwp->mainkey, XtNborderColor, back, NULL);
+                  XtVaSetValues(cwp->mainkey, XtNborderColor, focus, NULL);
                   return;
                   }
             }
@@ -245,15 +242,12 @@ static void set_focus(Widget w)
  CardPtr cp;
  CardWidgetsPtr cwp;
  int i;
- Pixel back, fore;
 
  bp = glbFirstBibListEl();
  while (bp!=NULL){
     cp = glbFirstCardListEl(bp);
     while (cp!=NULL){
        cwp = &cp->cw->ct.cw;
-       XtVaGetValues(cp->cw->cardWin, XtNbackground, &back, NULL);
-       XtVaGetValues(cp->cw->cardWin, XtNforeground, &fore, NULL);
        XtVaSetValues(cwp->mainkey, XtNborderColor, fore, NULL);
        if (cwp->owntype)
           XtVaSetValues(cwp->mainkey, XtNborderColor, fore, NULL);
@@ -266,7 +260,7 @@ static void set_focus(Widget w)
     bp = glbNextBibListEl(bp);
     }
  XtSetKeyboardFocus(XtParent(w), w);
- XtVaSetValues(w, XtNborderColor, back, NULL);
+ XtVaSetValues(w, XtNborderColor, focus, NULL);
 }
 
 
@@ -279,19 +273,21 @@ gucOpenCardWin (BibPtr bp, CardPtr cp, Boolean isNew)
 {
 CardWinPtr cw;
 CardWidgetsPtr cwp;
-Pixel fore, back;
+Dimension height;
   
    #ifdef ACTION_PROBLEM
    if (first_in){
    #endif
-   XtAppAddActions(XtWidgetToApplicationContext(topLevel), actions,
+   if (cotFocus()){
+      XtAppAddActions(XtWidgetToApplicationContext(topLevel), actions,
 		  XtNumber(actions));
+   }
    #ifdef ACTION_PROBLEM
    first_in = 0;
    }
    #endif
-
-   trans = XtParseTranslationTable(trans_string);
+   if (cotFocus())
+      trans = XtParseTranslationTable(trans_string);
 
    /* allocate memory for new element of window list */
    if ((cw = (CardWinPtr) XtCalloc(1, sizeof(CardWin))) == NULL) {
@@ -340,6 +336,8 @@ Pixel fore, back;
          	  commandWidgetClass, cw->cmdBox, NULL);
    cw->copy = XtVaCreateManagedWidget("copy", 
 	        commandWidgetClass, cw->cmdBox, NULL);
+   cw->crossref = XtVaCreateManagedWidget("crossref", 
+	        commandWidgetClass, cw->cmdBox, NULL);
    cw->close = XtVaCreateManagedWidget("quit", 
 	         commandWidgetClass, cw->cmdBox, NULL);
 
@@ -354,10 +352,16 @@ Pixel fore, back;
    else
       XtAddCallback(cw->change, XtNcallback, ccdChangeCardCmd, (XtPointer)cp);
    XtAddCallback(cw->copy, XtNcallback, ccdCopyCardCmd, (XtPointer)cp);
+   XtAddCallback(cw->crossref, XtNcallback, ccdOpenCrossrefCmd, (XtPointer)cp);
 
    /* create card window desktop */
    cw->cardDesk = XtVaCreateManagedWidget("carddesk",  
-	            formWidgetClass, cw->cardWin, NULL);
+	            viewportWidgetClass, cw->cardWin,
+		    XtNshowGrip, True,
+		    XtNallowVert, True,
+		    NULL);
+/*   cw->cardDesk = XtVaCreateManagedWidget("carddesk",  
+	            formWidgetClass, cw->cardWin, NULL); */
    cw->cardFlds = XtVaCreateManagedWidget(glbTypeToName(cp->cd->cardtype), 
 	            formWidgetClass, cw->cardDesk, NULL);
 
@@ -384,12 +388,19 @@ Pixel fore, back;
    /* build only widgets for specific card type */
    createWidgets(bp, cp);
    cwp = &cp->cw->ct.cw;
-
    XtPopup(cw->cardShell, XtGrabNone);
-   XtVaGetValues(cp->cw->cardWin, XtNbackground, &back, NULL);
-   XtVaGetValues(cp->cw->cardWin, XtNforeground, &fore, NULL);
-   XtSetKeyboardFocus(cw->cardFlds, cwp->mainkey);      
-   XtVaSetValues(cwp->mainkey, XtNborderColor, back, NULL);
+   XtVaGetValues(cw->cardShell, XtNheight, &height, NULL);
+   if (height > HeightOfScreen(XtScreen(topLevel)) - 100)
+      XtVaSetValues(cw->cardShell, XtNheight, 
+	   HeightOfScreen(XtScreen(topLevel)) - 100, NULL);
+
+   XtVaGetValues(cwp->mainkey, XtNbackground, &back, NULL);
+   XtVaGetValues(cwp->mainkey, XtNborderColor, &fore, NULL);
+   focus = options.focusColor;
+   if (cotFocus()){
+      XtSetKeyboardFocus(cw->cardFlds, cwp->mainkey);      
+      XtVaSetValues(cwp->mainkey, XtNborderColor, focus, NULL);
+      }
 
    return(OK);
 }
@@ -933,7 +944,8 @@ int i;
 		  	  XtNtop, XtChainTop, 
 		  	  XtNfromHoriz, cwp->mainkeyL, 
 			  NULL);
-   XtOverrideTranslations(cwp->mainkey, trans);
+   if (cotFocus())
+      XtOverrideTranslations(cwp->mainkey, trans);
    aktwidget = cwp->mainkey;
    if (cdp->cardtype == MAX_BIBTEX_TYPES){
       cwp->owntypeL = 	XtVaCreateManagedWidget("fieldLabel", 
@@ -946,7 +958,8 @@ int i;
 		  	  XtNstring, cdp->cardtypestr, 
 		    	  XtNfromVert, aktwidget, 
 		  	  XtNfromHoriz, cwp->owntypeL, NULL);
-      XtOverrideTranslations(cwp->owntype, trans);
+      if (cotFocus())
+         XtOverrideTranslations(cwp->owntype, trans);
       aktwidget = cwp->owntype;
    }
    for (i=0; i<max_fields; i++) {
@@ -961,7 +974,8 @@ int i;
 		  	  XtNstring, cdp->field[i], 
 		    	  XtNfromVert, aktwidget, 
 		  	  XtNfromHoriz, cwp->wfield[2*i], NULL);
-         XtOverrideTranslations(cwp->wfield[2*i+1], trans);
+         if (cotFocus())
+            XtOverrideTranslations(cwp->wfield[2*i+1], trans);
       if (isrequiredfield(i, cdp->cardtype))
          XtVaSetValues(cwp->wfield[2*i+1], XtNborderWidth, 3, NULL);
       aktwidget = cwp->wfield[2*i+1];
