@@ -51,7 +51,7 @@ static Errcode MakeListStrings (LstWinPtr lw);
 /* exported variables */
 /* ------------------ */
 
-listEntry list_layout;
+listEntry *list_layout;
 
 
 /* local global variables */
@@ -144,8 +144,8 @@ int i, lst_width;
 	             panedWidgetClass, lw->lstVp, NULL);
 
    lst_width = 0;
-   for (i=0; i<list_layout.number; i++)
-      lst_width += list_layout.width[i] + LST_WHITESPACE;
+   for (i=0; i<list_layout->number; i++)
+      lst_width += list_layout->width[i] + LST_WHITESPACE;
 
    if ((help = (String)XtCalloc(1, lst_width+1)) == NULL)
       return(ERR_NOMALLOC);
@@ -154,19 +154,19 @@ int i, lst_width;
       return(ERR_NOMALLOC);
       
    strcpy(sp, "");
-   for (i=0; i<list_layout.number; i++){
-      if (list_layout.field[i] == -1)
+   for (i=0; i<list_layout->number; i++){
+      if (list_layout->field[i] == -1)
          sprintf(help, "%-*.*s",
-              list_layout.width[i], list_layout.width[i], 
+              list_layout->width[i], list_layout->width[i], 
 	      "MAINKEY");
-      else if (list_layout.field[i] == -2)
+      else if (list_layout->field[i] == -2)
          sprintf(help, "%-*.*s",
-              list_layout.width[i], list_layout.width[i], 
+              list_layout->width[i], list_layout->width[i], 
 	      "CARDTYPE");
       else
          sprintf(help, "%-*.*s",
-              list_layout.width[i], list_layout.width[i], 
-	      glbFldToName(list_layout.field[i]));
+              list_layout->width[i], list_layout->width[i], 
+	      glbFldToName(list_layout->field[i]));
       sp = strcat(sp, help);
       sprintf(help, "%-*.*s",
  	    LST_WHITESPACE, LST_WHITESPACE, "");
@@ -402,18 +402,7 @@ gulCloseListWin (BibPtr bp)
          XtFree((char *)bp->lw->listArgv);
       if (bp->lw->strs)
          XtFree((char *)bp->lw->strs);
-      XtDestroyWidget(bp->lw->lstShell);
-      XtDestroyWidget(bp->lw->lstWin);
-      XtDestroyWidget(bp->lw->cmdBox);
-      XtDestroyWidget(bp->lw->save);
-      XtDestroyWidget(bp->lw->sort);
-      XtDestroyWidget(bp->lw->copy);
-      XtDestroyWidget(bp->lw->print);
-      XtDestroyWidget(bp->lw->quit);
-      XtDestroyWidget(bp->lw->lstVp);
-      XtDestroyWidget(bp->lw->vpWin);
-      XtDestroyWidget(bp->lw->headBox);
-      XtDestroyWidget(bp->lw->list);
+      XtPopdown(bp->lw->lstShell);
       dbtCardListDelete(&bp->lw->cardLst);
       bp->lw->cardLst = NULL;
       XtFree((char *)bp->lw->shellName);
@@ -558,8 +547,8 @@ int lst_width;
    }
 
    lst_width = 0;
-   for (i=0; i<list_layout.number; i++)
-      lst_width += list_layout.width[i] + LST_WHITESPACE;
+   for (i=0; i<list_layout->number; i++)
+      lst_width += list_layout->width[i] + LST_WHITESPACE;
 
 
    /* alloc new argv for Strings */
@@ -578,22 +567,22 @@ int lst_width;
 
    for (cl=lw->cardLst, sp=lw->listArgv; cl != NULL; cl=cl->next, sp++) {
       strcpy(*sp, "");
-      for (i=0; i<list_layout.number; i++){
-         if (list_layout.field[i] == -1)
+      for (i=0; i<list_layout->number; i++){
+         if (list_layout->field[i] == -1)
             sprintf(help, "%-*.*s",
-              list_layout.width[i], list_layout.width[i], 
+              list_layout->width[i], list_layout->width[i], 
 	      cl->data->mainkey);
-         else if (list_layout.field[i] == -2)
+         else if (list_layout->field[i] == -2)
             sprintf(help, "%-*.*s",
-              list_layout.width[i], list_layout.width[i], 
+              list_layout->width[i], list_layout->width[i], 
 	      cl->data->cardtypestr);
-         else if (!glbIsStringEmpty(cl->data->field[list_layout.field[i]]))
+         else if (!glbIsStringEmpty(cl->data->field[list_layout->field[i]]))
            sprintf(help, "%-*.*s",
-              list_layout.width[i], list_layout.width[i], 
-	      cl->data->field[list_layout.field[i]]);
+              list_layout->width[i], list_layout->width[i], 
+	      cl->data->field[list_layout->field[i]]);
          else
            sprintf(help, "%-*.*s",
-              list_layout.width[i], list_layout.width[i], "-----");
+              list_layout->width[i], list_layout->width[i], "-----");
          *sp = strcat(*sp, help);
          sprintf(help, "%-*.*s",
  	    LST_WHITESPACE, LST_WHITESPACE, "");
